@@ -16,8 +16,8 @@ from pygments import highlight
 from pygments.formatters.terminal256 import Terminal256Formatter
 from pygments.lexers import PythonTracebackLexer
 
-from prompt_toolkit import AbortAction, Exit
 from prompt_toolkit.utils import DummyContext
+from prompt_toolkit.contrib.shortcuts import create_eventloop, create_asyncio_eventloop
 
 from ptpython.python_input import PythonCommandLineInterface, PythonStyle
 
@@ -46,26 +46,22 @@ class PythonRepl(PythonCommandLineInterface):
         try:
             while True:
                 # Read
-                document = self.cli.read_input(
-                    on_abort=AbortAction.RETRY,
-                    on_exit=AbortAction.RAISE_EXCEPTION)
+                document = self.cli.read_input()
                 self._process_document(document)
-        except Exit:
+        except EOFError:
             pass
 
     def asyncio_start_repl(self):
         """
         (coroutine) Start a Read-Eval-print Loop for usage in asyncio. E.g.::
 
-            repl = PythonRepl(get_globals=lambda:globals())
+            repl = PythonRepl(eventloop, get_globals=lambda:globals())
             yield from repl.asyncio_start_repl()
         """
         try:
             while True:
                 # Read
-                g = self.cli.read_input_async(
-                    on_abort=AbortAction.RETRY,
-                    on_exit=AbortAction.RAISE_EXCEPTION)
+                g = self.cli.read_input_async()
 
                 # We use Python 2 syntax for delegating the coroutine and
                 # catching the returned document.
@@ -75,7 +71,7 @@ class PythonRepl(PythonCommandLineInterface):
                 except StopIteration as e:
                     document = e.args[0]
                     self._process_document(document)
-        except Exit:
+        except EOFError:
             pass
 
     def _process_document(self, document):
@@ -192,9 +188,18 @@ def embed(globals=None, locals=None, vi_mode=False, history_filename=None, no_co
     def get_locals():
         return locals
 
-    repl = PythonRepl(get_globals, get_locals, vi_mode=vi_mode, history_filename=history_filename,
+    # Create eventloop.
+    if return_asyncio_coroutine:
+        eventloop = create_asyncio_eventloop()
+    else:
+        eventloop = create_eventloop()
+
+    # Create REPL.
+    repl = PythonRepl(eventloop, get_globals, get_locals, vi_mode=vi_mode,
+                      history_filename=history_filename,
                       style=(None if no_colors else PythonStyle))
 
+    # Start repl.
     patch_context = repl.cli.patch_stdout_context() if patch_stdout else DummyContext()
 
     if return_asyncio_coroutine:
